# Contributing

Everybody is welcome
to contribute to this project.
Please make sure you have read
our [Code of Conduct](CODE_OF_CONDUCT.md).
You are expected to adhere to it.

The full documentation on contributing can be found at
[here](https://iniabu.readthedocs.io/en/latest/dev/index.html).

## Rough overview

- Development: We recommend using [rye](https://rye.astral.sh) for development.
- Testing: We use [pytest](https://docs.pytest.org/en/stable/).
- Documentation: We use [sphinx](https://www.sphinx-doc.org/en/master/).
- Code formatting: We use [ruff](https://astral.sh/ruff).
- Pre-commit hooks: We use [pre-commit](https://pre-commit.com/) to help you with formatting/linting.
